@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
 
 my %construct = (
@@ -28,6 +28,7 @@ my %construct = (
                  'auto-deref'      => 5.014,
                  '^GLOBAL_PHASE'   => 5.014,
                  '\o'              => 5.014,
+                 'package-block'   => 5.014,
 
                  'package-version' => 5.012,
                  '...'             => 5.012,
@@ -85,7 +86,7 @@ Syntax::Construct - Identify which non-feature constructs are used in the code.
 
 =head1 VERSION
 
-Version 0.14
+Version 0.15
 
 =head1 SYNOPSIS
 
@@ -216,7 +217,7 @@ L<perl5120delta/\N experimental regex escape>.
 =head3 while-readdir
 
 C<readdir> in a while-loop condition populates C<$_>. Not mentioned in
-any delta, but see L<perlfunc/readdir>.
+any delta, but see C<readdir> in L<perlfunc>.
 
 =head2 5.014
 
@@ -259,6 +260,10 @@ L<perl5140delta/Other Enhancements>.
 
 L<perl5140delta/Regular-expressions>.
 
+=head3 package-block
+
+See B<package block syntax> under L<perl5140delta/Syntactical Enhancements>.
+
 =head2 5.016
 
 No non-feature constructs were introduced in this version of Perl.
